<?php
/**
 * Thankyou page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/thankyou.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
do_action('ascend_woo_thank_you_start');
?>
<div class="woocommerce-order">

	<?php if ( $order ) : ?>

		<?php if ( $order->has_status( 'failed' ) ) : ?>

			<p class="woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed"><?php _e( 'Unfortunately your order cannot be processed as the originating bank/merchant has declined your transaction. Please attempt your purchase again.', 'ascend' ); ?></p>

			<p class="woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed-actions">
				<a href="<?php echo esc_url( $order->get_checkout_payment_url() ); ?>" class="button pay"><?php _e( 'Pay', 'ascend' ) ?></a>
				<?php if ( is_user_logged_in() ) : ?>
					<a href="<?php echo esc_url( wc_get_page_permalink( 'myaccount' ) ); ?>" class="button pay"><?php _e( 'My account', 'ascend' ); ?></a>
				<?php endif; ?>
			</p>

		<?php else : ?>

			<p class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', __( 'Thank you. Your order has been received.', 'ascend' ), $order ); ?></p>

			<ul class="woocommerce-order-overview woocommerce-thankyou-order-details order_details">

				<li class="woocommerce-order-overview__order order">
					<?php _e( 'Order number:', 'ascend' ); ?>
					<strong><?php echo $order->get_order_number(); ?></strong>
				</li>

				<li class="woocommerce-order-overview__date date">
					<?php _e( 'Date:', 'ascend' ); ?>
					<?php if ( version_compare( WC_VERSION, '3.0', '<' ) ) { ?>
						<strong><?php echo date_i18n( get_option( 'date_format' ), strtotime( $order->order_date ) ); ?></strong>
					<?php } else { ?>
						<strong><?php echo date_i18n( get_option( 'date_format' ), $order->get_date_created() ); ?></strong>
					<?php } ?>
				</li>

				<li class="woocommerce-order-overview__total total">
					<?php _e( 'Total:', 'ascend' ); ?>
					<strong><?php echo $order->get_formatted_order_total(); ?></strong>
				</li>
				<?php if ( version_compare( WC_VERSION, '3.0', '<' ) ) { ?>
					<?php if ( $order->payment_method_title ) : ?>
					<li class="method">
						<?php _e( 'Payment Method:', 'ascend' ); ?>
						<strong><?php echo $order->payment_method_title; ?></strong>
					</li>
					<?php endif; 
				} else {
					if ( $order->get_payment_method_title() ) : ?>

					<li class="woocommerce-order-overview__payment-method method">
						<?php _e( 'Payment method:', 'ascend' ); ?>
							<strong><?php echo wp_kses_post( $order->get_payment_method_title() ); ?></strong>
					</li>

					<?php endif;
				} ?>

			</ul>

		<?php endif; ?>
		<?php if ( version_compare( WC_VERSION, '3.0', '<' ) ) { ?>
			<?php do_action( 'woocommerce_thankyou_' . $order->payment_method, $order->id ); ?>
			<?php do_action( 'woocommerce_thankyou', $order->id ); ?>
		<?php } else { ?>
			<?php do_action( 'woocommerce_thankyou_' . $order->get_payment_method(), $order->get_id() ); ?>
			<?php do_action( 'woocommerce_thankyou', $order->get_id() ); ?>
		<?php } ?>

	<?php else : ?>

		<p class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', __( 'Thank you. Your order has been received.', 'ascend' ), null ); ?></p>

	<?php endif; ?>

</div>